﻿using System;
using System.Windows.Forms;

using DevExpress.XtraEditors;
using DevExpress.XtraMap;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load += Form_Load;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            #region 맵 컨트롤을 설정한다.

            MapControl mapControl = new MapControl();

            mapControl.Parent = this;
            mapControl.Dock   = DockStyle.Fill;

            #endregion
            #region OPEN STREET MAP 데이터 공급자를 설정한다.

            OpenStreetMapDataProvider openStreetMapDataProvider = new OpenStreetMapDataProvider();

            openStreetMapDataProvider.CacheOptions.DiskFolder     = "C://MapTiles"; 
            openStreetMapDataProvider.CacheOptions.DiskExpireTime = new TimeSpan(1, 0, 0);
            openStreetMapDataProvider.CacheOptions.MemoryLimit    = 64;           
            openStreetMapDataProvider.CacheOptions.DiskLimit      = 200;

            openStreetMapDataProvider.WebRequest += openStreetMapDataProvider_WebRequest;

            #endregion
            #region 이미지 레이어를 설정한다.

            ImageLayer imageLayer = new ImageLayer();

            imageLayer.DataProvider = openStreetMapDataProvider;

            mapControl.Layers.Add(imageLayer);

            #endregion
        }

        #endregion
        #region OPEN STREET MAP 데이터 공급자 웹 요청시 처리하기 - openStreetMapDataProvider_WebRequest(sender, e)

        /// <summary>
        /// OPEN STREET MAP 데이터 공급자 웹 요청시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void openStreetMapDataProvider_WebRequest(object sender, MapWebRequestEventArgs e)
        {
            e.UserAgent = "XtraMap Getting Started - Connect to OpenStreetMap";
        }

        #endregion
    }
}